Crate lido

Crate lido 

Modules

account_map
A type that stores a map (dictionary) from public key to some value T.
accounts
Contains a utility macro that makes it safer to work with lists of accounts.
balance
Logic for keeping the stake pool balanced.
error
Error types
instruction
metrics
Data structures for tracking metrics on-chain.
processor
Program state processor
stake_account
Utilities for dealing with stake accounts.
state
State transition types
token
Types to make working with token balances safer.
util

Macros

accounts_struct
Generates two structs for passing accounts by name.
accounts_struct_meta
Implementation detail of [accounts_struct].

Constants

MAXIMUM_UNSTAKE_ACCOUNTS
The maximum number of unstake accounts that a validator can have simultaneously.
MINIMUM_STAKE_ACCOUNT_BALANCE
The minimum amount to put in a stake account (1 SOL).
MINT_AUTHORITY
Mint authority, mints StSol.
RESERVE_ACCOUNT
Seed for reserve account that holds SOL.
REWARDS_WITHDRAW_AUTHORITY
Authority responsible for withdrawing the stake rewards.
STAKE_AUTHORITY
Seed for managing the stake.
VALIDATOR_STAKE_ACCOUNT
Additional seed for active/activating validator stake accounts.
VALIDATOR_UNSTAKE_ACCOUNT
Additional seed for inactive/deactivating validator stake accounts.

Functions

find_authority_program_address
Finds the public key and bump seed for a given authority. Since this function can take some time to run, it’s preferred to use Pubkey::create_program_address(seeds, program_id) inside programs.