pub struct CollectValidatorFeeMeta {
pub lido: Pubkey,
pub validator_vote_account: Pubkey,
pub st_sol_mint: Pubkey,
pub mint_authority: Pubkey,
pub treasury_st_sol_account: Pubkey,
pub developer_st_sol_account: Pubkey,
pub reserve: Pubkey,
pub rewards_withdraw_authority: Pubkey,
}
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,