Struct lido::state::FeeRecipients [−][src]
Specifies the fee recipients, accounts that should be created by Lido’s minter
Fields
treasury_account: Pubkeydeveloper_account: PubkeyTrait Implementations
impl BorshDeserialize for FeeRecipients where
Pubkey: BorshDeserialize,
Pubkey: BorshDeserialize,
impl BorshDeserialize for FeeRecipients where
Pubkey: BorshDeserialize,
Pubkey: BorshDeserialize,
Get the name of the type without brackets.
Recursively, using DFS, add type definitions required for this type. For primitive types this is an empty map. Type definition explains how to serialize/deserialize a type. Read more
fn add_definition(
declaration: String,
definition: Definition,
definitions: &mut HashMap<String, Definition, RandomState>
)
fn add_definition(
declaration: String,
definition: Definition,
definitions: &mut HashMap<String, Definition, RandomState>
)
Helper method to add a single type definition to the map.
Returns the “default value” for a type. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.