Struct lido::state::RewardDistribution [−][src]
pub struct RewardDistribution {
pub treasury_fee: u32,
pub validation_fee: u32,
pub developer_fee: u32,
pub st_sol_appreciation: u32,
}Expand description
Determines how rewards are split up among these parties, represented as the number of parts of the total. For example, if each party has 1 part, then they all get an equal share of the reward.
Fields
treasury_fee: u32validation_fee: u32developer_fee: u32st_sol_appreciation: u32Implementations
Split the reward according to the distribution defined in this instance.
Fees are all rounded down, and the remainder goes to stSOL appreciation.
This means that the outputs may not sum to the input, even when
st_sol_appreciation is 0.
Returns the fee amounts in SOL. stSOL should be minted for those when they get distributed. This acts like a deposit: it is like the fee recipients received their fee in SOL outside of Solido, and then deposited it. The remaining SOL, which is not taken as a fee, acts as a donation to the pool, and makes the SOL value of stSOL go up. It is not included in the output, as nothing needs to be done to handle it.